@@ -13,24 +13,24 @@ import org.gnu.glib.Handle;
 import org.gnu.glib.Struct;
 
 /**
- * Class for memory management of structs.  Should be renamed to
- * Struct once we rename org.javagnome.Struct to org.javagnome.Proxy.
+ * Class for memory management of structs. Should be renamed to Struct once we
+ * rename org.javagnome.Struct to org.javagnome.Proxy.
  */
-public class MemStruct extends Struct 
-{
-    public MemStruct() {}
-
-    public MemStruct( Handle handle ) {
-        super( handle );
+public class MemStruct extends Struct {
+    public MemStruct() {
     }
 
-    public static MemStruct getMemStructFromHandle( Handle handle ) {
-        return (MemStruct)handle.getProxiedObject();
+    public MemStruct(Handle handle) {
+        super(handle);
+    }
+
+    public static MemStruct getMemStructFromHandle(Handle handle) {
+        return (MemStruct) handle.getProxiedObject();
     }
 
     protected void finalize() throws Throwable {
-        //log.fine(this.getClass().getName());
-    	
+        // log.fine(this.getClass().getName());
+
         // If an exception is throws in the constructor of a sublcass, then
         // an object with a null handle may be finalized at some point. Don't
         // run nativeFinalize for those objects.
@@ -38,8 +38,7 @@ public class MemStruct extends Struct
             if (getHandle() != null) {
                 nativeFinalize(getHandle());
             }
-        }
-        finally {
+        } finally {
             super.finalize();
         }
     }
@@ -47,8 +46,8 @@ public class MemStruct extends Struct
     static {
         init();
     }
-    
+
     native static final private void nativeFinalize(Handle handle);
+
     native static final private void init();
 }
-
