@@ -13,6 +13,7 @@
 #include <cairo.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gdk_Pixbuf.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -435,8 +436,8 @@ JNIEXPORT jbyteArray JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1save_1to_1buff
     gsize size;
     jbyteArray ret_val;
     ret_val = NULL;
-	jboolean val = gdk_pixbuf_save_to_bufferv(pixbuf_g, &b, &size, t, k, v, &error_g);
-    if (NULL != error_g)
+    gdk_pixbuf_save_to_bufferv(pixbuf_g, &b, &size, t, k, v, &error_g);
+    if (error_g != NULL)
     	updateStructHandle(env, error, error_g, (JGFreeFunc) g_error_free);
     else	{
     	ret_val = (*env)->NewByteArray(env, (jsize) size);
@@ -668,7 +669,7 @@ JNIEXPORT jbyteArray JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1get_1option (J
     jsize result_len = result_g ? strlen (result_g) : 0;
     jbyteArray result_j = result_g ? (*env)->NewByteArray (env, result_len) : NULL;
     if (result_g) 
-    	(*env)->SetByteArrayRegion (env, result_j, 0, result_len, (const jbyte*)result_g);
+    	(*env)->SetByteArrayRegion (env, result_j, 0, result_len, (jbyte*)result_g);
     return result_j;
 }
 
