@@ -10,9 +10,11 @@
 #include <jni.h>
 #include <glib.h>
 #include <gdk/gdkpixbuf.h>
+#include <gdk/gdk.h>
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_glib_Value.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -219,7 +221,8 @@ JNIEXPORT jint JNICALL Java_org_gnu_glib_Value_g_1value_1get_1int
   (JNIEnv *env, jclass cls, jobject value) 
 {
     GValue *value_g;
-    gint result;
+    gint result = 0;
+    gboolean result_good = TRUE;
 	
     value_g = (GValue *)getPointerFromHandle(env, value);
 
@@ -231,9 +234,15 @@ JNIEXPORT jint JNICALL Java_org_gnu_glib_Value_g_1value_1get_1int
     } else if (G_VALUE_HOLDS_ENUM(value_g)) {
         result = g_value_get_enum (value_g);
     } else {
+        result_good = FALSE;
     }
     gdk_threads_leave();
-    
+
+    if (FALSE == result_good) {
+    	JNU_ThrowByName(env, "java.lang.IllegalArgumentException",
+                "Value does not hold an integer.");
+    }
+
     return result;
 }
 
@@ -263,7 +272,8 @@ JNIEXPORT jlong JNICALL Java_org_gnu_glib_Value_g_1value_1get_1long
   (JNIEnv *env, jclass cls, jobject value) 
 {
     GValue *value_g;
-    jlong result;
+    jlong result = 0;
+    jboolean result_good = TRUE;
 	
     value_g = (GValue *)getPointerFromHandle(env, value);
 
@@ -277,9 +287,15 @@ JNIEXPORT jlong JNICALL Java_org_gnu_glib_Value_g_1value_1get_1long
     } else if (G_VALUE_HOLDS_UINT64(value_g)) {
         result = g_value_get_uint64 (value_g);
     } else {
+        result_good = FALSE;
     }
     gdk_threads_leave();
     
+    if (FALSE == result_good) {
+    	JNU_ThrowByName(env, "java.lang.IllegalArgumentException",
+                "Value does not hold a long.");
+    }
+
     return result;
 }
 
@@ -494,7 +510,7 @@ JNIEXPORT void JNICALL Java_org_gnu_glib_Value_g_1value_1set_1java_1object
  * Function used by Java_org_gnu_glib_Value_g_1value_1get_1java_1object
  * to return a new java.lang.Integer object with the value integer_j
  */
-jobject createNewIntegerInstance(JNIEnv *env, jint integer_j) 
+static jobject createNewIntegerInstance(JNIEnv *env, jint integer_j) 
 {
     jclass integerClass = (*env)->FindClass(env, "java/lang/Integer");
     if (integerClass == NULL)
@@ -510,7 +526,7 @@ jobject createNewIntegerInstance(JNIEnv *env, jint integer_j)
  * Function used by Java_org_gnu_glib_Value_g_1value_1get_1java_1object
  * to return a new java.lang.Long object with the value long_j
  */
-jobject createNewLongInstance(JNIEnv *env, jlong long_j) 
+static jobject createNewLongInstance(JNIEnv *env, jlong long_j) 
 {
     jclass longClass = (*env)->FindClass(env, "java/lang/Long");
     if (longClass == NULL)
@@ -526,7 +542,7 @@ jobject createNewLongInstance(JNIEnv *env, jlong long_j)
  * Function used by Java_org_gnu_glib_Value_g_1value_1get_1java_1object
  * to return a new java.lang.Float object with the value float_j
  */
-jobject createNewFloatInstance(JNIEnv *env, jfloat float_j) 
+static jobject createNewFloatInstance(JNIEnv *env, jfloat float_j) 
 {
     jclass floatClass = (*env)->FindClass(env, "java/lang/Float");
     if (floatClass == NULL)
@@ -542,7 +558,7 @@ jobject createNewFloatInstance(JNIEnv *env, jfloat float_j)
  * Function used by Java_org_gnu_glib_Value_g_1value_1get_1java_1object
  * to return a new java.lang.Double object with the value double_j
  */
-jobject createNewDoubleInstance(JNIEnv *env, jdouble double_j) 
+static jobject createNewDoubleInstance(JNIEnv *env, jdouble double_j) 
 {
     jclass doubleClass = (*env)->FindClass(env, "java/lang/Double");
     if (doubleClass == NULL)
@@ -558,7 +574,7 @@ jobject createNewDoubleInstance(JNIEnv *env, jdouble double_j)
  * Function used by Java_org_gnu_glib_Value_g_1value_1get_1java_1object
  * to return a new java.lang.Boolean object with the value boolean_j
  */
-jobject createNewBooleanInstance(JNIEnv *env, jboolean boolean_j) 
+static jobject createNewBooleanInstance(JNIEnv *env, jboolean boolean_j) 
 {
     jclass booleanClass = (*env)->FindClass(env, "java/lang/Boolean");
     if (booleanClass == NULL)
@@ -574,7 +590,7 @@ jobject createNewBooleanInstance(JNIEnv *env, jboolean boolean_j)
  * Function used by Java_org_gnu_glib_Value_g_1value_1get_1java_1object
  * to return a java.lang.Enum object with the value enum_int
  */
-jobject getEnumInstance(JNIEnv *env, GValue *value_g) 
+static jobject getEnumInstance(JNIEnv *env, GValue *value_g) 
 {
     char *enumClassName = javaobject_from_gtktype(G_VALUE_TYPE(value_g));
     char *internSignature = g_malloc(64);
