@@ -14,6 +14,7 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gtk_Widget.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -307,10 +308,10 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1set_1accel_1path (JN
  * Method:    gtk_widget_list_accel_closures
  * Signature: (I)I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1list_1accel_1closures (JNIEnv *env, jclass cls, jobject widget) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1list_1accel_1closures (JNIEnv *env, jclass cls, jobject widget) 
 {
     GtkWidget *widget_g = (GtkWidget *)getPointerFromHandle(env, widget);
-    return (jint)gtk_widget_list_accel_closures (widget_g);
+    return getStructHandle(env, gtk_widget_list_accel_closures (widget_g), NULL, (JGFreeFunc) g_free);
 }
 
 /*
@@ -421,12 +422,12 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1intersect
  * Method:    gtk_widget_region_intersect
  * Signature: (II)I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1region_1intersect (JNIEnv *env, 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1region_1intersect (JNIEnv *env, 
                                                                                jclass cls, jobject widget, jobject region) 
 {
     GtkWidget *widget_g = (GtkWidget *)getPointerFromHandle(env, widget);
     GdkRegion *region_g = (GdkRegion *)getPointerFromHandle(env, region);
-    return (jint)gtk_widget_region_intersect (widget_g, region_g);
+    return getGObjectHandle(env, G_OBJECT(gtk_widget_region_intersect (widget_g, region_g)));
 }
 
 /*
@@ -650,7 +651,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1get_1parent (JNIE
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1get_1parent_1window (JNIEnv *env, jclass cls, jobject widget) 
 {
     GtkWidget *widget_g = (GtkWidget *)getPointerFromHandle(env, widget);
-    return getGObjectHandle(env, (GObject *) gtk_widget_get_parent_window (widget_g));
+    return getGObjectHandleAndRef(env, (GObject *) gtk_widget_get_parent_window (widget_g));
 }
 
 /*
@@ -662,7 +663,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1get_1window (JNIE
 {
     GtkWidget *widget_g = (GtkWidget *)getPointerFromHandle(env, widget);
     GObject *obj = (GObject *) (GTK_WIDGET_NO_WINDOW(widget_g) ? NULL : widget_g->window);
-    return getGObjectHandle(env, obj);
+    return getGObjectHandleAndRef(env, obj);
 }
 
 /*
@@ -1415,6 +1416,29 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1remove_1mnemonic_1la
     gtk_widget_remove_mnemonic_label(widget_g, label_g);
 }
 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Widget_gtk_1widget_1get_1allocation (JNIEnv *env, jclass cls, 
+ jobject widget)
+{
+    jclass allocationClass;
+    jmethodID constructor;
+
+    GtkWidget *widget_g = (GtkWidget *)getPointerFromHandle(env, widget);
+
+    allocationClass = (*env)->FindClass(env, "org/gnu/gtk/Allocation");
+	 
+     if ( NULL == allocationClass )
+        return (jobject)NULL;
+	 
+    constructor = (*env)->GetMethodID(env, allocationClass, "<init>", "(IIII)V");
+	 
+    if ( NULL == constructor)
+       return (jobject)NULL;
+
+    return (*env)->NewObject(env, allocationClass, constructor, 
+							 widget_g->allocation.x, widget_g->allocation.y,
+							 widget_g->allocation.width, widget_g->allocation.height);
+}
+
 /****************************************
  * Drag and Drop Support
  ****************************************/
